@@ -14,7 +14,6 @@
 .import GCompris 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 
-var currentLevel;
 var numberOfLevel;
 var items;
 var dataset;
@@ -83,10 +82,10 @@ var quantityInstructions = [
 
 function start(items_) {
     items = items_;
-    currentLevel = 0;
     dataset = items.levels;
     numberOfLevel = dataset.length;
-    items.score.currentSubLevel = 1;
+    items.currentLevel = Core.getInitialLevel(numberOfLevel);
+    items.score.currentSubLevel = 0;
     firstNumberList = [];
 
     if(!items.tutorialImage.visible) {
@@ -98,15 +97,15 @@ function stop() {
 }
 
 function initLevel() {
-    items.bar.level = currentLevel + 1;
-    var data = dataset[currentLevel];
+    items.errorRectangle.resetState();
+    var data = dataset[items.currentLevel];
     items.score.numberOfSubLevels = data.numberOfSubLevels;
     items.draggedItems.clear();
     items.droppedItems.clear();
     items.largestNumberRepresentation.clear();
     items.typeResult = false;
-    minimumValue = dataset[currentLevel].minValue;
-    maximumValue = dataset[currentLevel].maxValue;
+    minimumValue = dataset[items.currentLevel].minValue;
+    maximumValue = dataset[items.currentLevel].maxValue;
 
     checkAvailableQuestions();
 
@@ -137,38 +136,35 @@ function initLevel() {
             largestNumber -= squaresNumber;
         }
     }
+    items.buttonsBlocked = false;
 }
 
 function nextLevel() {
-    if(numberOfLevel <= ++currentLevel) {
-        currentLevel = 0;
-    }
-    items.score.currentSubLevel = 1;
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getNextLevel(items.currentLevel, numberOfLevel);
+    items.score.currentSubLevel = 0;
     initLevel();
 }
 
 function previousLevel() {
-    if(--currentLevel < 0) {
-        currentLevel = numberOfLevel - 1;
-    }
-    items.score.currentSubLevel = 1;
+    items.score.stopWinAnimation();
+    items.currentLevel = Core.getPreviousLevel(items.currentLevel, numberOfLevel);
+    items.score.currentSubLevel = 0;
     initLevel();
 }
 
 function nextSubLevel() {
     if(items.score.currentSubLevel >= items.score.numberOfSubLevels) {
-        nextLevel();
-        return;
+        items.bonus.good('flower');
+    } else {
+        items.droppedItems.clear();
+
+        // In case number of sublevels are greater than the number of possibilities of the current level.
+        checkAvailableQuestions();
+
+        displayDecimalNumberQuestion();
+        items.buttonsBlocked = false;
     }
-
-    items.droppedItems.clear();
-
-    // In case number of sublevels are greater than the number of possibilities of the current level.
-    checkAvailableQuestions();
-
-    displayDecimalNumberQuestion();
-
-    items.score.currentSubLevel++;
 }
 
 function checkAvailableQuestions() {
@@ -230,7 +226,7 @@ function generateFirstNumber() {
 
 function generateSecondNumber() {
     if(items.isAdditionMode) {
-        maximumValue = dataset[currentLevel].maxValue;
+        maximumValue = dataset[items.currentLevel].maxValue;
         maximumValue -= generatedNumber;
     }
 
@@ -269,6 +265,7 @@ function displayDecimalNumberQuestion() {
 }
 
 function verifyNumberRepresentation() {
+    items.buttonsBlocked = true;
     var i;
     var sum = 0;
 
@@ -292,15 +289,20 @@ function verifyNumberRepresentation() {
 
     if(sum === correctAnswer) {
         if(items.isSubtractionMode || items.isAdditionMode) {
+            items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
             items.numpad.resetText();
             items.typeResult = true;
+            items.buttonsBlocked = false;
         }
         else {
-            items.bonus.good("flower");
+            items.score.currentSubLevel += 1;
+            items.score.playWinAnimation();
+            items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
         }
     }
     else {
-        items.bonus.bad("flower");
+        items.errorRectangle.startAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
     }
 }
 
@@ -317,12 +319,15 @@ function calculateCorrectAnswer() {
 }
 
 function verifyNumberTyping(typedAnswer) {
+    items.buttonsBlocked = true;
     typedAnswer = typedAnswer.replace("," , ".");
     if(parseFloat(typedAnswer) === parseFloat(correctAnswer)) {
-        items.bonus.good("flower");
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+        items.bonus.good('flower')
     }
     else {
-        items.bonus.bad("flower");
+        items.errorRectangle.startAnimation();
+        items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/crash.wav");
     }
 }
 
